@@ -218,8 +218,8 @@ our %Modules = (
     },
 
     'Compress::Raw::Bzip2' => {
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.213.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Wed Aug 28 14:11:20 2024',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.214.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sat Oct 25 11:33:29 2025',
         'FILES'        => q[cpan/Compress-Raw-Bzip2],
         'EXCLUDED'     => [
             qr{^t/Test/},
@@ -231,8 +231,8 @@ our %Modules = (
     },
 
     'Compress::Raw::Zlib' => {
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.213.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Wed Aug 28 13:58:29 2024',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.214.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sat Oct 25 11:20:02 2025',
         'FILES'    => q[cpan/Compress-Raw-Zlib],
         'EXCLUDED' => [
             qr{^examples/},
@@ -528,7 +528,7 @@ our %Modules = (
     },
 
     'ExtUtils::ParseXS' => {
-        'DISTRIBUTION' => 'LEONT/ExtUtils-ParseXS-3.59.tar.gz',
+        'DISTRIBUTION' => 'LEONT/ExtUtils-ParseXS-3.60.tar.gz',
         'FILES'        => q[dist/ExtUtils-ParseXS],
     },
 
@@ -669,8 +669,8 @@ our %Modules = (
     },
 
     'IO-Compress' => {
-        'DISTRIBUTION' => 'PMQS/IO-Compress-2.213.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Wed Aug 28 14:24:42 2024',
+        'DISTRIBUTION' => 'PMQS/IO-Compress-2.214.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sat Oct 25 11:58:55 2025',
         'MAIN_MODULE'  => 'IO::Compress::Base',
         'FILES'        => q[cpan/IO-Compress],
         'EXCLUDED'     => [
@@ -835,7 +835,7 @@ our %Modules = (
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20250820.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20251022.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -1090,8 +1090,8 @@ our %Modules = (
     },
 
     'Term::Table' => {
-        'DISTRIBUTION' => 'EXODIST/Term-Table-0.025.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Sun Aug 31 22:13:35 2025',
+        'DISTRIBUTION' => 'EXODIST/Term-Table-0.027.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sat Nov 15 21:20:44 2025',
         'FILES'        => q[cpan/Term-Table],
         'EXCLUDED'     => [
             qw( appveyor.yml ),
@@ -1121,8 +1121,8 @@ our %Modules = (
     },
 
     'Test::Simple' => {
-        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302214.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Fri Jun 27 06:54:11 2025',
+        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302216.tar.gz',
+        'SYNCINFO'     => 'tib on Mon Nov 17 11:43:13 2025',
         'FILES'        => q[cpan/Test-Simple],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1256,8 +1256,8 @@ our %Modules = (
     },
 
     'Time::Piece' => {
-        'DISTRIBUTION' => 'ESAYM/Time-Piece-1.3701.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Sun Aug 31 22:21:48 2025',
+        'DISTRIBUTION' => 'ESAYM/Time-Piece-1.41.tar.gz',
+        'SYNCINFO'     => 'tib on Fri Nov 14 11:59:09 2025',
         'FILES'        => q[cpan/Time-Piece],
         'EXCLUDED'     => [ qw[reverse_deps.txt] ],
     },
