@@ -9,14 +9,14 @@ use warnings;
 use bytes;
 
 use IO::File;
-use IO::Uncompress::RawInflate  2.213 ;
-use IO::Compress::Base::Common  2.213 qw(:Status );
-use IO::Uncompress::Adapter::Inflate  2.213 ;
-use IO::Uncompress::Adapter::Identity 2.213 ;
-use IO::Compress::Zlib::Extra 2.213 ;
-use IO::Compress::Zip::Constants 2.213 ;
+use IO::Uncompress::RawInflate  2.214 ;
+use IO::Compress::Base::Common  2.214 qw(:Status );
+use IO::Uncompress::Adapter::Inflate  2.214 ;
+use IO::Uncompress::Adapter::Identity 2.214 ;
+use IO::Compress::Zlib::Extra 2.214 ;
+use IO::Compress::Zip::Constants 2.214 ;
 
-use Compress::Raw::Zlib  2.213 () ;
+use Compress::Raw::Zlib  2.214 () ;
 
 BEGIN
 {
@@ -24,13 +24,13 @@ BEGIN
    local $SIG{__DIE__};
 
     eval{ require IO::Uncompress::Adapter::Bunzip2 ;
-          IO::Uncompress::Adapter::Bunzip2->VERSION(2.213) } ;
+          IO::Uncompress::Adapter::Bunzip2->VERSION(2.214) } ;
     eval{ require IO::Uncompress::Adapter::UnLzma ;
-          IO::Uncompress::Adapter::UnLzma->VERSION(2.213) } ;
+          IO::Uncompress::Adapter::UnLzma->VERSION(2.214) } ;
     eval{ require IO::Uncompress::Adapter::UnXz ;
-          IO::Uncompress::Adapter::UnXz->VERSION(2.213) } ;
+          IO::Uncompress::Adapter::UnXz->VERSION(2.214) } ;
     eval{ require IO::Uncompress::Adapter::UnZstd ;
-          IO::Uncompress::Adapter::UnZstd->VERSION(2.213) } ;
+          IO::Uncompress::Adapter::UnZstd->VERSION(2.214) } ;
 }
 
 
@@ -38,13 +38,13 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnzipError, %headerLookup);
 
-$VERSION = '2.213';
+$VERSION = '2.214';
 $UnzipError = '';
 
 @ISA    = qw(IO::Uncompress::RawInflate Exporter);
 @EXPORT_OK = qw($UnzipError unzip );
 %EXPORT_TAGS = %IO::Uncompress::RawInflate::EXPORT_TAGS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 Exporter::export_ok_tags('all');
 
 %headerLookup = (
@@ -2012,7 +2012,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2025 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
