@@ -365,7 +365,7 @@ S_output_non_portable(pTHX_ const U8 base)
 }
 
 UV
-Perl_grok_bin_oct_hex(pTHX_ const char *start,
+Perl_grok_bin_oct_hex(pTHX_ const char * const start,
                         STRLEN *len_p,
                         I32 *flags,
                         NV *result,
@@ -376,23 +376,8 @@ Perl_grok_bin_oct_hex(pTHX_ const char *start,
                      )
 
 {
-    const char *s0 = start;
-    const char *s;
-    STRLEN len = *len_p;
-    STRLEN bytes_so_far;    /* How many real digits have been processed */
-    UV value = 0;
-    NV value_nv = 0;
-    const PERL_UINT_FAST8_T base = 1 << shift;  /* 2, 8, or 16 */
-    const UV max_div= UV_MAX / base;    /* Value above which, the next digit
-                                           processed would overflow */
-    const I32 input_flags = *flags;
-    const bool allow_underscores =
-                                cBOOL(input_flags & PERL_SCAN_ALLOW_UNDERSCORES);
-    bool overflowed = FALSE;
-
-    /* In overflows, this keeps track of how much to multiply the overflowed NV
-     * by as we continue to parse the remaining digits */
-    NV factor = 0;
+    PERL_ARGS_ASSERT_GROK_BIN_OCT_HEX;
+    ASSUME(inRANGE(shift, 1, 4) && shift != 2);
 
     /* This function unifies the core of grok_bin, grok_oct, and grok_hex.  It
      * is optimized for hex conversion.  For example, it uses XDIGIT_VALUE to
@@ -410,37 +395,41 @@ Perl_grok_bin_oct_hex(pTHX_ const char *start,
      *      ...
      */
 
-    PERL_ARGS_ASSERT_GROK_BIN_OCT_HEX;
-
-    ASSUME(inRANGE(shift, 1, 4) && shift != 2);
-
+    const I32 input_flags = *flags;
     /* Clear output flags; unlikely to find a problem that sets them */
     *flags = 0;
 
+    const bool allow_underscores =
+             cBOOL(input_flags & ( PERL_SCAN_ALLOW_UNDERSCORES
+                                  |PERL_SCAN_ALLOW_MEDIAL_UNDERSCORES_ONLY));
+    const char * s = start;
+    const char * e = start + *len_p;
+
     if (!(input_flags & PERL_SCAN_DISALLOW_PREFIX)) {
 
         /* strip off leading b or 0b; x or 0x.
            for compatibility silently suffer "b" and "0b" as valid binary; "x"
            and "0x" as valid hex numbers. */
-        if (len >= 1) {
-            if (isALPHA_FOLD_EQ(s0[0], prefix)) {
-                s0++;
-                len--;
+        if (e - s > 1) {
+            if (isALPHA_FOLD_EQ(s[0], prefix)) {
+                s++;
             }
-            else if (len >= 2 && s0[0] == '0' && (isALPHA_FOLD_EQ(s0[1], prefix))) {
-                s0+=2;
-                len-=2;
+            else if (   e - s > 2
+                     && s[0] == '0'
+                     && (isALPHA_FOLD_EQ(s[1], prefix)))
+            {
+                s += 2;
             }
         }
     }
 
-    s = s0; /* s0 potentially advanced from 'start' */
+    const char * const s0 = s; /* Where the significant digits start */
+    UV value = 0;
 
     /* Unroll the loop so that the first 8 digits are branchless except for the
      * switch.  A ninth hex one overflows a 32 bit word. */
-    switch (len) {
-      case 0:
-          return 0;
+  redo_switch:
+    switch (e - s) {
       default:
           if (UNLIKELY(! generic_isCC_(*s, class_bit)))  break;
           value = (value << shift) | XDIGIT_VALUE(*s);
@@ -479,33 +468,57 @@ Perl_grok_bin_oct_hex(pTHX_ const char *start,
       case 1:
           if (UNLIKELY(! generic_isCC_(*s, class_bit)))  break;
           value = (value << shift) | XDIGIT_VALUE(*s);
-
-          if (LIKELY(len <= 8)) {
+          s++;
+          /* FALLTHROUGH */
+      case 0:
+          if (LIKELY(s >= e)) {
               return value;
           }
 
-          s++;
+          /* If we get here, and the accumulated value is still 0, it is
+           * because there are more leading zeros than the cases of this
+           * switch(),  These are common enough with these kinds of
+           * binary-style numbers that it is worth this extra conditional to
+           * continue absorbing them via the switch. */
+          if (value == 0) {
+              goto redo_switch;
+          }
+
           break;
     }
 
-    bytes_so_far = s - s0;
-    factor = shift << bytes_so_far;
-    len -= bytes_so_far;
+    /* How many real digits have been processed */
+    STRLEN bytes_so_far = s - s0;
 
-    for (; len--; s++) {
+    /* In overflows, this keeps track of how much to multiply the overflowed NV
+     * by as we continue to parse the remaining digits */
+    NV factor = shift << bytes_so_far;
+
+    bool overflowed = FALSE;
+    NV value_nv = 0;
+    const PERL_UINT_FAST8_T base = 1 << shift;  /* 2, 8, or 16 */
+
+    for (; s < e; s++) {
         if (generic_isCC_(*s, class_bit)) {
             /* Write it in this wonky order with a goto to attempt to get the
                compiler to make the common case integer-only loop pretty tight.
                With gcc seems to be much straighter code than old scan_hex.
                (khw suspects that adding a LIKELY() just above would do the
                same thing) */
-          redo:
-            if (LIKELY(value <= max_div)) {
-                value = (value << shift) | XDIGIT_VALUE(*s);
+          redo: ;
+
+            /* Make room for the next digit */
+            UV tentative_value = value << shift;
+
+            /* If shiftng back doesn't yield the previous value, it was
+             * because a bit got shifted off the left end, so overflowed.
+             * But if it worked, add the new digit. */
+            if (LIKELY((tentative_value >> shift) == value)) {
+                value = tentative_value | XDIGIT_VALUE(*s);
                     /* Note XDIGIT_VALUE() is branchless, works on binary
                      * and octal as well, so can be used here, without
                      * slowing those down */
-                factor *= 1 << shift;
+                factor *= base;
                 continue;
             }
 
@@ -522,13 +535,14 @@ Perl_grok_bin_oct_hex(pTHX_ const char *start,
              * 'value_nv' eventually, either when all digits are gone, or we
              * have overflowed this fresh start. */
             value = XDIGIT_VALUE(*s);
-            factor = 1 << shift;
+            factor = base;
 
             if (! overflowed) {
                 overflowed = TRUE;
-                if (   ! (input_flags & PERL_SCAN_SILENT_OVERFLOW)
-                    &&    ckWARN_d(WARN_OVERFLOW))
-                {
+                if (input_flags & PERL_SCAN_SILENT_OVERFLOW) {
+                    *flags |= PERL_SCAN_SILENT_OVERFLOW;
+                }
+                else if (ckWARN_d(WARN_OVERFLOW)) {
                     warner(packWARN(WARN_OVERFLOW),
                            "Integer overflow in %s number",
                            (base == 16) ? "hexadecimal"
@@ -541,19 +555,27 @@ Perl_grok_bin_oct_hex(pTHX_ const char *start,
         }
 
         if (   *s == '_'
-            && len
+            && s < e - 1
             && allow_underscores
             && generic_isCC_(s[1], class_bit)
 
                 /* Don't allow a leading underscore if the only-medial bit is
                  * set */
             && (   LIKELY(s > s0)
-                || UNLIKELY((input_flags & PERL_SCAN_ALLOW_MEDIAL_UNDERSCORES)
-                                        != PERL_SCAN_ALLOW_MEDIAL_UNDERSCORES)))
+                || UNLIKELY(! (  input_flags
+                               & PERL_SCAN_ALLOW_MEDIAL_UNDERSCORES_ONLY))))
         {
-            --len;
             ++s;
-            goto redo;
+
+            /* To get here with the value so-far being 0 means we've only had
+             * leading zeros, then an underscore.  We can continue with the
+             * branchless switch() instead of this loop */
+            if (value == 0) {
+                goto redo_switch;
+            }
+            else {
+                goto redo;
+            }
         }
 
         if (*s) {
@@ -592,10 +614,10 @@ Perl_grok_bin_oct_hex(pTHX_ const char *start,
 
     if (LIKELY(! overflowed)) {
 #if UVSIZE > 4
-        if (      UNLIKELY(value > 0xffffffff)
-            && ! (input_flags & PERL_SCAN_SILENT_NON_PORTABLE))
-        {
-            output_non_portable(base);
+        if (UNLIKELY(value > 0xffffffff)) {
+            if (! (input_flags & PERL_SCAN_SILENT_NON_PORTABLE)) {
+                output_non_portable(base);
+            }
             *flags |= PERL_SCAN_SILENT_NON_PORTABLE;
         }
 #endif
@@ -742,12 +764,12 @@ If an infinity or a not-a-number is recognized, C<*sp> will point to
 one byte past the end of the recognized string.  If the recognition fails,
 zero is returned, and C<*sp> will not move.
 
-=for apidoc Amnh|bool|IS_NUMBER_GREATER_THAN_UV_MAX
-=for apidoc Amnh|bool|IS_NUMBER_INFINITY
-=for apidoc Amnh|bool|IS_NUMBER_IN_UV
-=for apidoc Amnh|bool|IS_NUMBER_NAN
-=for apidoc Amnh|bool|IS_NUMBER_NEG
-=for apidoc Amnh|bool|IS_NUMBER_NOT_INT
+=for apidoc Amnh||IS_NUMBER_GREATER_THAN_UV_MAX
+=for apidoc Amnh||IS_NUMBER_INFINITY
+=for apidoc Amnh||IS_NUMBER_IN_UV
+=for apidoc Amnh||IS_NUMBER_NAN
+=for apidoc Amnh||IS_NUMBER_NEG
+=for apidoc Amnh||IS_NUMBER_NOT_INT
 
 =cut
 */
@@ -998,8 +1020,8 @@ Perl_grok_infnan(pTHX_ const char** sp, const char* send)
 =for apidoc      grok_number
 =for apidoc_item grok_number_flags
 
-Look for a number in the C<len> bytes starting at C<pv>.  If one isn't found,
-return 0; otherwise return its type (and optionally its value).  In
+Look for a base 10 number in the C<len> bytes starting at C<pv>.  If one isn't
+found, return 0; otherwise return its type (and optionally its value).  In
 C<grok_number> all C<len> bytes must be either leading C<L</isSPACE>>
 characters or part of the number.  The same is true in C<grok_number_flags>
 unless C<flags> contains the C<PERL_SCAN_TRAILING> bit, which allows for
@@ -1516,7 +1538,7 @@ Perl_my_atof(pTHX_ const char* s)
 =for apidoc      my_atof
 =for apidoc_item Atof
 
-These each are L<C<atof>(3)>, but properly work with Perl locale handling,
+These each are C<L<atof(3)>>, but properly work with Perl locale handling,
 accepting a dot radix character always, but also the current locale's radix
 character if and only if called from within the lexical scope of a Perl C<use
 locale> statement.
