@@ -10,6 +10,7 @@
  */
 
 #define YYEMPTY		(-2)
+#define PERL_IDENTIFIER_LENGTH  (256 * MAX_UNICODE_UTF8_BYTES)
 
 typedef struct {
     YYSTYPE val;    /* semantic value */
@@ -31,6 +32,10 @@ typedef struct yy_lexshared {
     SV			*re_eval_str;	/* "(?{...})" text */
 } LEXSHARED;
 
+/* Opaque struct of data relevant during parsing and construction of a
+ * subroutine signature. Defined and used exclusively by op.c */
+typedef struct yy_parser_signature yy_parser_signature;
+
 typedef struct yy_parser {
 
     /* parser state */
@@ -56,7 +61,7 @@ typedef struct yy_parser {
     char	*lex_casestack;	/* what kind of case mods in effect */
     U8		lex_defer;	/* state after determined token */
     U8		lex_dojoin;	/* doing an array interpolation
-				   1 = @{...}  2 = ->@ */
+                                   1 = @{...}  2 = ->@ */
     U8		expect;		/* how to interpret ambiguous tokens */
     bool	preambled;
     bool        sub_no_recover; /* can't recover from a sublex error */
@@ -70,8 +75,8 @@ typedef struct yy_parser {
     SV		*lex_stuff;	/* runtime pattern from m// or s/// */
     I32		multi_start;	/* 1st line of multi-line string */
     I32		multi_end;	/* last line of multi-line string */
-    UV		multi_open;	/* delimiter of said string */
-    UV		multi_close;	/* delimiter of said string */
+    UV		multi_open;	/* delimiter code point of said string */
+    UV		multi_close;	/* delimiter code point of said string */
     bool        lex_re_reparsing; /* we're doing G_RE_REPARSING */
     U8		lex_super_state;/* lexer state to save */
     U16		lex_sub_inwhat;	/* "lex_inwhat" to use in sublex_push */
@@ -81,8 +86,8 @@ typedef struct yy_parser {
     LEXSHARED	*lex_shared;
     SV		*linestr;	/* current chunk of src text */
     char	*bufptr;	/* carries the cursor (current parsing
-				   position) from one invocation of yylex
-				   to the next */
+                                   position) from one invocation of yylex
+                                   to the next */
     char	*oldbufptr;	/* in yylex, beginning of current token */
     char	*oldoldbufptr;	/* in yylex, beginning of previous token */
     char	*bufend;	
@@ -108,17 +113,14 @@ typedef struct yy_parser {
     U8		lex_fakeeof;	/* precedence at which to fake EOF */
     U8		lex_flags;
     COP		*saved_curcop;	/* the previous PL_curcop */
-    char	tokenbuf[256];
+    char	tokenbuf[ PERL_IDENTIFIER_LENGTH ];
     line_t	herelines;	/* number of lines in here-doc */
     line_t	preambling;	/* line # when processing $ENV{PERL5DB} */
 
-    /* these are valid while parsing a subroutine signature */
-    UV          sig_elems;      /* number of signature elements seen so far */
-    UV          sig_optelems;   /* number of optional signature elems seen */
-    char        sig_slurpy;     /* the sigil of the slurpy var (or null) */
+    yy_parser_signature *signature; /* parser state of a subroutine signature */
     bool        sig_seen;       /* the currently parsing sub has a signature */
 
-    bool        recheck_utf8_validity;
+    bool        recheck_charset_validity;
 
     PERL_BITFIELD16	in_pod:1;      /* lexer is within a =pod section */
     PERL_BITFIELD16	filtered:1;    /* source filters in evalbytes */
@@ -137,8 +139,8 @@ typedef struct yy_parser {
 # define LEX_START_COPIED	0x00000008
 # define LEX_DONT_CLOSE_RSFP	0x00000010
 # define LEX_START_FLAGS \
-	(LEX_START_SAME_FILTER|LEX_START_COPIED \
-	|LEX_IGNORE_UTF8_HINTS|LEX_EVALBYTES|LEX_DONT_CLOSE_RSFP)
+        (LEX_START_SAME_FILTER|LEX_START_COPIED \
+        |LEX_IGNORE_UTF8_HINTS|LEX_EVALBYTES|LEX_DONT_CLOSE_RSFP)
 #endif
 
 /* flags for parser API */
