@@ -110,7 +110,63 @@
 #  define PERL_STATIC_FORCE_INLINE_NO_RET __declspec(noreturn) __forceinline static
 #endif
 
-#define  WIN32_LEAN_AND_MEAN
+#ifdef PERL_CORE
+#  ifndef PERL_CORE_NO_CPAN_W32_H /* unsanctioned unsupported bypass for CPAN */
+#    define NOATOM            /* GUI IPC RPC strings */
+#    define NOCLIPBOARD
+#    define NOCOLOR           /* Widget colors */
+#    define NOCOMM            /* Serial ports*/
+#    define NOCRYPT           /* Encryption and employee auth tap cards */
+#    define NOCTLMGR          /* "Control and Dialog routines" */
+#    define NODEFERWINDOWPOS  /* Z index resize app windows */
+#    define NODRAWTEXT        /* Fonts "DrawText() and DT_*" */
+#    define NOGDI             /* wikipedia "Computer_graphics_algorithms" */
+#    define NOGDICAPMASKS     /* PNP Monitors/Screens */
+#    define NOHELP            /* Help engine */
+#    define NOICONS           /* Icon Img Objs */
+#    define NOIMAGE           /* MS .h says #def for perf, but OBSOL/UNIMPL/FUT */
+#    define NOKANJI
+#    define NOKERNEL          /* MS .h says #def for perf, but OBSOL/UNIMPL/FUT */
+#    define NOKEYSTATES       /* Mouse */
+#    define NOMB              /* popup MessageBox() */
+#    define NOMCX             /* Dialup Modem */
+#    define NOMEMMGR          /* GUI IPC RPC malloc buffers */
+#    define NOMENUS           /* GUI Menu obj */
+#    define NOMETAFILE        /* file format for half rendered graphics */
+#    undef NOMINMAX           /* "Macros min(a,b) and max(a,b)" OBSOL/UNIMPL/FUT */
+#    define NOMINMAX
+#    define NOMSG             /* GUI Message loop */
+/* #define NONLS              "Wide" Code Page conversion APIs */
+/* OBSOL/UNIMPL/FUT "OpenFile(), OemToAnsi, AnsiToOem" etc */
+#    define NOOPENFILE
+#    define NOPROFILER        /* "Profiler interface." OBSOL/UNIMPL/FUT */
+#    define NOPROXYSTUB       /* MS COM DCOM RPC probably, undoced, unimpl */
+#    define NORASTEROPS       /* see NOGDI */
+#    define NORPC
+#    define NOSCROLL          /* App Window Objs */
+#    define NOSERVICE         /* root/semi kernel service processes */
+#    define NOSHOWWINDOW      /* App Window Objs */
+#    define NOSOUND
+#    define NOSYSCOMMANDS     /* App Window Objs */
+#    define NOSYSMETRICS      /* Screen resolution */
+#    define NOTAPE            /* Tape drives */
+#    define NOTEXTMETRIC      /* Fonts */
+#    ifndef PERL_IN_WIN32_PERLLIB_C
+#      define NOUSER          /* high level GUI/IPC/RPC */
+#    endif
+#    define NOVIRTUALKEYCODES /* Keyboards */
+#    define NOWH              /* SetWindowsHook */
+#    ifndef PERL_IN_WIN32_PERLLIB_C
+#      define NOWINMESSAGES   /* GUI Message loop IPC/RPC */
+#    endif
+#    define NOWINOFFSETS      /* App Window Obj themes */
+#    define NOWINSTYLES       /* App Window Obj themes */
+#    define OEMRESOURCE       /* Mouse cursor file format */
+#    define VC_EXTRALEAN      /* "MFC" VC 2010s or older??? */
+#  endif
+#endif
+
+#define  WIN32_LEAN_AND_MEAN /* Day 1 Win32 Perl port, CPAN expects this. */
 #include <windows.h>
 
 /*
@@ -204,10 +260,10 @@ struct utsname {
 
 /* access() mode bits */
 #ifndef R_OK
-#  define	R_OK	4
-#  define	W_OK	2
-#  define	X_OK	1
-#  define	F_OK	0
+#  define R_OK  4
+#  define W_OK  2
+#  define X_OK  1
+#  define F_OK  0
 #endif
 
 /* for waitpid() */
@@ -259,8 +315,10 @@ union PerlNan { unsigned __int64 __q; double __d; };
 extern const __declspec(selectany) union PerlNan __PL_nan_u = { 0x7FF8000000000000UI64 };
 #define NV_NAN ((NV)__PL_nan_u.__d)
 
+#endif /* ifdef _MSC_VER */
+
 /* The CRT was rewritten in VS2015. */
-#if _MSC_VER >= 1900
+#ifdef _UCRT
 
 /* No longer declared in stdio.h */
 EXTERN_C char *gets(char* buffer);
@@ -274,7 +332,7 @@ typedef struct
     {
         FILE  _public_file;
         char* _ptr;
-    };
+    } u;
 
     char*            _base;
     int              _cnt;
@@ -289,17 +347,13 @@ typedef struct
 #define PERLIO_FILE_flag_RD 0x0001 /* _IOREAD   */
 #define PERLIO_FILE_flag_WR 0x0002 /* _IOWRITE  */
 #define PERLIO_FILE_flag_RW 0x0004 /* _IOUPDATE */
-#define PERLIO_FILE_ptr(f)  (((__crt_stdio_stream_data*)(f))->_ptr)
+#define PERLIO_FILE_ptr(f)  (((__crt_stdio_stream_data*)(f))->u._ptr)
 #define PERLIO_FILE_base(f) (((__crt_stdio_stream_data*)(f))->_base)
 #define PERLIO_FILE_cnt(f)  (((__crt_stdio_stream_data*)(f))->_cnt)
 #define PERLIO_FILE_flag(f) ((int)(((__crt_stdio_stream_data*)(f))->_flags))
 #define PERLIO_FILE_file(f) (*(int*)(&((__crt_stdio_stream_data*)(f))->_file))
 
-#endif
-
-#endif /* _MSC_VER */
-
-#if (!defined(_MSC_VER)) || (defined(_MSC_VER) && _MSC_VER < 1900)
+#else /* ifdef _UCRT */
 
 /* Note: PERLIO_FILE_ptr/base/cnt are not actually used for GCC or <VS2015
  * since FILE_ptr/base/cnt do the same thing anyway but it doesn't hurt to
@@ -525,6 +579,9 @@ struct interp_intern {
     HWND        message_hwnd;
     UINT	timerid;
     unsigned 	poll_count;
+#ifdef USE_ITHREADS
+    DWORD       cur_tid;
+#endif
     Sighandler_t sigtable[SIG_SIZE];
 };
 
